@@ -1,6 +1,5 @@
 use crate::netrc::netrc;
 
-use failure::format_err;
 use url::Url;
 
 #[derive(Debug)]
@@ -30,16 +29,16 @@ impl PartialEq for ParsedAddress {
 }
 
 impl ParsedAddress {
-    pub fn parse_address(address: &str) -> ParsedAddress {
-        let netrc = netrc();
+    pub fn parse_address(address: &str, silent: bool) -> ParsedAddress {
+        let netrc = netrc(silent);
         let url = Url::parse(address).unwrap();
         let server = format!(
             "{}:{}",
             url.host_str()
-                .ok_or_else(|| format_err!("failed to parse hostname from url: {}", url))
+                .ok_or_else(|| panic!("failed to parse hostname from url: {}", url))
                 .unwrap(),
             url.port_or_known_default()
-                .ok_or_else(|| format_err!("failed to parse port from url: {}", url))
+                .ok_or_else(|| panic!("failed to parse port from url: {}", url))
                 .unwrap(),
         );
         let username = if url.username().is_empty() {
@@ -53,14 +52,14 @@ impl ParsedAddress {
 
         let mut path_segments: Vec<String> = url
             .path_segments()
-            .ok_or_else(|| format_err!("failed to get url path segments: {}", url))
+            .ok_or_else(|| panic!("failed to get url path segments: {}", url))
             .unwrap()
             .map(|s| s.to_string())
             .collect();
 
         let file = path_segments
             .pop()
-            .ok_or_else(|| format_err!("got empty path segments from url: {}", url))
+            .ok_or_else(|| panic!("got empty path segments from url: {}", url))
             .unwrap();
 
         ParsedAddress {
@@ -149,7 +148,7 @@ async fn parse_works() {
         file: "file".to_string(),
     };
 
-    let actual = ParsedAddress::parse_address("ftp://user:pass@do.main:21/index/file");
+    let actual = ParsedAddress::parse_address("ftp://user:pass@do.main:21/index/file", true);
 
     assert_eq!(actual, expected);
 }
@@ -208,7 +207,7 @@ async fn parse_works_with_netrc_mixin() {
     let data = "machine do.main login test password p@ssw0rd port 21";
 
     std::fs::write(".netrc.test", data).expect("Unable to write file");
-    let actual = ParsedAddress::parse_address("ftp://do.main/index/file");
+    let actual = ParsedAddress::parse_address("ftp://do.main/index/file", true);
 
     assert_eq!(actual, expected);
     std::fs::remove_file(".netrc.test").unwrap();
